/******************************************************************************/
/* TIME.C: Time Functions for 1000Hz Clock Tick                               */
/******************************************************************************/
/* This file is part of the uVision/ARM development tools.                    */
/* Copyright (c) 2005-2006 Keil Software. All rights reserved.                */
/* This software may only be used under the terms of a valid, current,        */
/* end user licence from KEIL for a compatible version of KEIL software       */
/* development tools. Nothing else gives you the right to use this software.  */
/******************************************************************************/

#include <S3C44B0X.H>                       /* S3C44B0X definitions */

#define MCLK 66735000                       /* Master Clock */
#define TCLK     1000                       /* Timer Clock  */

#define TCNT5 (MCLK/TCLK/2)                  /* Timer Counts */
                                             // Prescaller = off, divider = /2

volatile unsigned long timeval;             /* Current Time Tick */


__irq void HandlerTIMER5 (void) {           /* Timer 5 Interrupt Handler */

  timeval++;                                /* Increment Time Tick  */
  pIC->I_ISPC = INT_TIMER5;                 /* Clear Interrupt Flag */
}


void init_timer (void) {                    
	
	pPWM->TCON  = 0;                          // Init TCON
	
	/* Setup Timer 0  */	
	pPWM->TCFG0  = 0x000000FF;                // Prescaller for TMR0 & TMR1 = 0xFF
	pPWM->TCFG1  = MUX0_1_8;
	pPWM->TCNTB0 = 0x07;                      /* Timer 0 Period */
	pPWM->TCMPB0 = 0x02;
	pPWM->TCON  |=  (T0_AUTOREL | T0_UPDATE); /* Update TCNCTB0, Auto Reload */
	pPWM->TCON  &= ~(T0_UPDATE);              /* Update TCNCTB0 */
	
	
	/* Setup Timer 5 with Interrupt */
  pPWM->TCNTB5 = TCNT5 - 1;                 /* Timer 5 Period */
  pPWM->TCON   |= (T5_UPDATE | T5_AUTOREL | T5_START);  /* Update, Start Timer 5 (Auto Reload)*/
	pPWM->TCON  &= ~(T5_UPDATE);  
	
  pIC->INTMSK &= ~(INT_GLOBAL |             /* Global Interrupt Enable  */
                   INT_TIMER5);             /* Timer 5 Interrupt Enable */
  pIC->INTCON  = FIQ_DISABLE |              /* Disable FIQ */
                 IRQ_ENABLE  |              /* Enable IRQ  */
                 VECT_IRQ;                  /* IRQ Vectored Interrupt Mode */
	
}
